@@ -1,11 +1,13 @@
 <?php
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
- * @version $Id: innodb.lib.php 10689 2007-10-02 08:38:17Z cybot_tm $
+ * @version $Id$
+ * @package phpMyAdmin-Engines
  */
 
 /**
  *
+ * @package phpMyAdmin-Engines
  */
 class PMA_StorageEngine_innodb extends PMA_StorageEngine
 {
@@ -229,14 +231,19 @@ class PMA_StorageEngine_innodb extends PMA_StorageEngine
                 . '            <td class="value">'
                 . PMA_formatNumber($status['Innodb_buffer_pool_pages_misc'], 0) . "\n"
                 . '</td>' . "\n"
-                . '        </tr>' . "\n"
-                . '        <tr class="even">' . "\n"
-                . '            <th>' . $GLOBALS['strLatchedPages'] . '</th>' . "\n"
+                . '        </tr>';
+
+            // not present at least since MySQL 5.1.40
+            if (isset($status['Innodb_buffer_pool_pages_latched'])) {
+                $output .= '        <tr class="even">'
+                . '            <th>' . $GLOBALS['strLatchedPages'] . '</th>'
                 . '            <td class="value">'
-                . PMA_formatNumber($status['Innodb_buffer_pool_pages_latched'], 0) . "\n"
-                . '</td>' . "\n"
-                . '        </tr>' . "\n"
-                . '    </tbody>' . "\n"
+                . PMA_formatNumber($status['Innodb_buffer_pool_pages_latched'], 0)
+                . '</td>'
+                . '        </tr>';
+            }
+
+            $output .= '    </tbody>' . "\n"
                 . '</table>' . "\n\n"
                 . '<table class="data" id="table_innodb_bufferpool_activity">' . "\n"
                 . '    <caption class="tblHeaders">' . "\n"
@@ -331,6 +338,53 @@ class PMA_StorageEngine_innodb extends PMA_StorageEngine
     {
         return 'innodb';
     }
+
+    /**
+     *  
+     * Gets the InnoDB plugin version number 
+     * http://www.innodb.com/products/innodb_plugin 
+     * (do not confuse this with phpMyAdmin's storage engine plugins!)
+     *
+     * @return string the version number, or empty if not running as a plugin 
+     */
+    function getInnodbPluginVersion()
+    {
+        return PMA_DBI_fetch_value('SELECT @@innodb_version;');
+    }
+
+    /**
+     *  
+     * Gets the InnoDB file format 
+     * (works only for the InnoDB plugin)
+     * http://www.innodb.com/products/innodb_plugin 
+     * (do not confuse this with phpMyAdmin's storage engine plugins!)
+     *
+     * @return string the InnoDB file format 
+     */
+    function getInnodbFileFormat()
+    {
+        return PMA_DBI_fetch_value("SHOW GLOBAL VARIABLES LIKE 'innodb_file_format';", 0, 1);
+    }
+
+    /**
+     *  
+     * Verifies if this server supports the innodb_file_per_table feature 
+     * (works only for the InnoDB plugin)
+     * http://www.innodb.com/products/innodb_plugin 
+     * (do not confuse this with phpMyAdmin's storage engine plugins!)
+     *
+     * @return boolean whether this feature is supported or not 
+     */
+    function supportsFilePerTable()
+    {
+        $innodb_file_per_table = PMA_DBI_fetch_value("SHOW GLOBAL VARIABLES LIKE 'innodb_file_per_table';", 0, 1);
+        if ($innodb_file_per_table == 'ON') {
+            return true;
+        } else {
+            return false;
+        }
+
+    }
 }
 
 ?>
